<?php

declare(strict_types=1);

namespace Drupal\Tests\otlog;

use OpenTelemetry\API\Logs\LogRecord;

/**
 * Introspectable log record.
 */
class IntrospectableLogRecord extends LogRecord {

  public function __construct(LogRecord $logRecord) {
    parent::__construct($logRecord->body);
    $this->timestamp = $logRecord->timestamp;
    $this->observedTimestamp = $logRecord->observedTimestamp;
    $this->context = $logRecord->context;
    $this->severityNumber = $logRecord->severityNumber;
    $this->severityText = $logRecord->severityText;
    $this->attributes = $logRecord->attributes;
  }

  /**
   * Returns the log message body.
   */
  public function getBody(): string {
    return $this->body;
  }

  /**
   * Returns the log timestamp in nanoseconds.
   */
  public function getTimestamp(): ?int {
    return $this->timestamp;
  }

  /**
   * Returns the observed timestamp in nanoseconds.
   */
  public function getObservedTimestamp(): ?int {
    return $this->observedTimestamp;
  }

  /**
   * Returns the severity number.
   */
  public function getSeverityNumber(): int {
    return $this->severityNumber;
  }

  /**
   * Returns the severity text.
   */
  public function getSeverityText(): ?string {
    return $this->severityText;
  }

  /**
   * Returns the attributes.
   */
  public function getAttributes(): array {
    return $this->attributes;
  }

}
